Google Sites Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Google Sites Baseline Report

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## SITES-1 Sites Service Status

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.SITES.1.1v0.5 | Sites Service SHOULD be disabled for all users. | Pass | Should | Requirement met in all OUs and groups.